/*
  Java gfx-test framework

   Copyright (C) 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;



import org.gfxtest.framework.CommonBitmapOperations;
import org.gfxtest.framework.PrintTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test check the rendering of buffered images (so called bit block
 * transfers or Bit Blt) created by various constructors.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.PRINT_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.MIRROR)
@Transformation(Transformations.NONE)
@Zoom(1)
public class PrintTestBitBltMirrorImage extends PrintTest
{
    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * No flip is performed to that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryNoFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, false, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Horizontal flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryHorizontalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, true, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Vertical flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, false, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Horizontal and vertical flips are performed on that image..
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryHorizontalAndVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, true, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * No flip is performed to that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBNoFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, false, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Horizontal flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBHorizontalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, true, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Vertical flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, false, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Horizontal and vertical flips are performed on that image..
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBHorizontalAndVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, true, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * No flip is performed to that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRNoFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, false, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Horizontal flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRHorizontalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, true, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Vertical flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, false, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Horizontal and vertical flips are performed on that image..
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRHorizontalAndVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, true, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * No flip is performed to that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBNoFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, false, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Horizontal flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBHorizontalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, true, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Vertical flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, false, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Horizontal and vertical flips are performed on that image..
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBHorizontalAndVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, true, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * No flip is performed to that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_PreNoFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, false, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Horizontal flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_PreHorizontalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, true, false);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Vertical flip is performed on that image.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_PreVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, false, true);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Horizontal and vertical flips are performed on that image..
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_PreHorizontalAndVerticalFlip(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, true, true);
    }
    
    /**
     * Entry point to the test suite.
     * 
     * @param args
     *            not used in this case
     */
    public static void main(String[] args)
    {
        new PrintTestBitBltMirrorImage().runTestSuite(args);
    }
}
